@@ -313,9 +313,13 @@ def format_result(msg, prefix):
     _test = color_other(basename(msg["result_test"]))
     _indent = f"{strftimedelta(msg['message_rtime']):>20}" + f"{'':3}{indent * (msg['test_id'].count('/') - 1)}"
 
+    _result_message = msg["result_message"]
+    if _result_message and settings.trim and int(msg["test_level"]) > 1:
+        _result_message = _result_message.strip().split("\n", 1)[0].strip()
+
     out = (f"{color_other(_indent)}{_result} "
         f"{_test}{color_other(', ' + msg['result_test'])}"
-        f"{(color_other(', ') + _color(format_multiline(msg['result_message'], ' ' * len(_indent)).strip())) if msg['result_message'] else ''}"
+        f"{(color_other(', ') + _color(format_multiline(_result_message, ' ' * len(_indent)).strip())) if _result_message else ''}"
         f"{(color_other(', ') + _color(msg['result_reason'])) if msg['result_reason'] else ''}\n")
 
     return out
